@@ -1,52 +1,75 @@
 # -*- coding: utf-8 -*-
 
 '''
-
 @author: KaueBonfim
 '''
 from time import sleep
 from selenium.webdriver.support.events import EventFiringWebDriver
-from .Drivers import Instancia_driver,Instancia_driver_Angular
-from .mouse_teclado import Teclado
-from .mouse_teclado import Mouse
-from .Verifica import Valida
-from .Error import Elemento_erro
-from .web_extensao import Aguarde_elemento,Js_Script,Simula,Alerta,MyListener
+from Pyautomators.mouse_teclado import Teclado,Mouse
+from Pyautomators.Verifica import Valida
+from Pyautomators.web_extensao import Espera,Js_Script,Simula,Alerta,MyListener,Condicoes_de_aguarde,select_model,Tipos_de_elemento,Teclas_para_driver
+from selenium import webdriver
 from selenium.webdriver import ActionChains
-
-
+from Pyautomators.Error import Driver_erro,Elemento_erro
+from Pyautomators.Drivers import Firefox,Chrome
 ''' Este arquivo prove os metodos em selenium para web,
     na qual os passamos um elemento chave e seu tipo e ele executa a acao descrita'''
 
 
-class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
+class Web(Teclado,Mouse,Valida,Espera,Js_Script,Simula):
     ''' Esta classe tem o intuito de prover conexão com selenium em web'''
-    def __init__(self,drive,path_driver=None,Angular=False,options=None,log_name=None):
+    def __init__(self,driver,path_driver=None,options=None,binarios=None):
         '''No construtor temos um parametros sendo um obrigatorio
         driver(obrigatorio):Qual dos drivers a serem usados
         path_driver:Local Aonde esta o Driver web usado
-        options:as configurações passadas pelo options do driver
-        Angular:Vai ser caso o site for feito inteiramente em angular
+        options:as configuraÃ§Ãµes passadas pelo options do driver
         '''
-        
-        self.drive=drive
-        if(Angular==False):
-            self.drivin=Instancia_driver().get_driver(drive,path_driver,options)
-            if(log_name != None):
-                self.driver=EventFiringWebDriver(self.drivin,MyListener(log_name))
-            else:
-                self.driver=self.drivin
-            self.angular=Angular
-        else:
+                  
+        if(driver == 'Chrome'):
+            if(path_driver==None):
+                path_driver="chromedriver"
+            self.__driver=Chrome(path_driver=path_driver,opcoes=options,binario=binarios).get_driver()  
+            self.driver=EventFiringWebDriver(self.__driver,MyListener())
+        elif(driver == 'Firefox'):  
+            if(path_driver==None):
+                path_driver="geckodriver"          
+            self.__driver=Firefox(path_driver=path_driver,options=options,binario=binarios).get_driver()
+            self.driver=EventFiringWebDriver(self.__driver,MyListener())
             
-            self.driver=Instancia_driver_Angular().get_driver(drive,path_driver,options)
-           
-            self.angular=Angular
+                    
+        elif(driver == 'Ie'):    
+            if(path_driver==None):
+                path_driver="IEDriverServer.exe"          
+            self.driver=webdriver.Ie(executable_path=path_driver)
+            
+        elif(driver == 'Edge'):    
+            if(path_driver==None):
+                path_driver="MicrosoftWebDriver.exe"          
+            self.driver=webdriver.Edge(executable_path=path_driver)
+        else:
+            Erro="""
+                NÃ£o é um driver de servidor valido!
+                Digite um driver valido:
+                
+                Ie
+                Firefox
+                Chrome    
+                Edge 
+                    """
+            raise Driver_erro(Erro) 
+            
+            
+    
+        
+        
+        
+        
         self.alert=Alerta(self.driver)
         self.ActionChains=ActionChains(self.driver)
-        self.tipo='web'
-                
-       
+        self.Condicao=Condicoes_de_aguarde()
+        self.select=select_model
+        self.tipo=Tipos_de_elemento
+        self.teclas=Teclas_para_driver
         
     def print_janela(self,path_imagem):
         '''Este metodo tira um print do conteudo atual da janela sendo usada
@@ -59,6 +82,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         
         self.driver.get_screenshot_as_file(path_imagem)
         
+    
         
     def fechar_programa(self):
         '''Este metodo fecha o driver web
@@ -130,7 +154,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         get_navegador()'''
         return self.driver.name
     
-    def elemento(self,elemento,tipo,implicit=0):
+    def elemento(self,elemento,tipo,implicit=None):
         r'''Esta procura um elemento e retorna o objeto do elemento
         parametros:
         elemento(obrigatorio):elemento que deve ser procurado
@@ -161,16 +185,10 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         css:    Web    <p class="content">Site content goes here.</p> = 'p.content'
         
         partial_link:    Web    <a href="continue.html">Continue</a> = 'Conti'
-        
-        android:    Mobile 
-        
-        ios:    Mobile
-        
-        binding:    Web(Angular) <span>{{person.name}}</span> = 'person.name' ou <span ng-bind="person.email"></span> = 'person.email'
-        
-        model:    Web(Angular) <input type="text" ng-model="person.name"/> = 'person.name'       
-        '''    
-        self.driver.implicitly_wait(implicit)
+           
+        '''  
+        if(implicit!=None):  
+            self.driver.implicitly_wait(implicit)
         if(tipo == 'id'):
             element=self.driver.find_element_by_id(elemento)
         elif(tipo == 'name'):
@@ -187,30 +205,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
             element=self.driver.find_element_by_css_selector(elemento) 
         elif(tipo == 'partial_link'):            
             element=self.driver.find_element_by_partial_link_text(elemento) 
-        elif(self.angular==False):
-            if(tipo=='binding'):
-                element=self.driver.find_element_by_binding(elemento)
-            elif(tipo=='model'):
-                element=self.driver.find_element_by_model(elemento)
-            elif(tipo=='accessibility_id'):
-                element=self.driver.find_element_by_accessibility_id(elemento)
-            else:
-                Erro="""
-                    Escolha um valor de elemento Valido
-                    lista de elementos:
-                    id:    Web
-                    name:    Web
-                    class:    Web
-                    xpath:    Web
-                    link:    Web
-                    tag:    Web
-                    css:    Web
-                    partial_link:    Web
-                    binding:    Web(Angular)
-                    model:    Web(Angular)
-                    
-                    """
-                raise Elemento_erro(Erro)
+        
         else:
             Erro="""
                 Escolha um valor de elemento Valido
@@ -232,7 +227,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
             raise Elemento_erro(Erro)
         return element
       
-    def elemento_list(self,elemento,tipo,indice_lista,implicit=0):
+    def elemento_list(self,elemento,tipo,indice_lista,implicit=None):
         '''Esta procura um elemento  dentro de uma lista de elementos com o mesmo parametro
         parametros:
         elemento(obrigatorio):elemento que deve ser procurado
@@ -266,17 +261,14 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         partial_link:    Web    <a href="continue.html">Continue</a> = 'Conti'
        
         
-        binding:    Web(Angular) <span>{{person.name}}</span> = 'person.name' ou <span ng-bind="person.email"></span> = 'person.email'
-        
-        model:    Web(Angular) <input type="text" ng-model="person.name"/> = 'person.name'
-         
         '''
-        self.driver.implicitly_wait(implicit)
+        if(implicit!=None):  
+            self.driver.implicitly_wait(implicit)
         elements=self.elementos_list(elemento, tipo, implicit)
         element=elements[indice_lista]
         return element
     
-    def elementos_list(self,elemento,tipo,implicit=0):
+    def elementos_list(self,elemento,tipo,implicit=None):
         '''Esta procura todos os elementos de elementos com o mesmo parametro
         parametros:
         elemento(obrigatorio):elemento que deve ser procurado
@@ -308,12 +300,11 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         
         partial_link:    Web    <a href="continue.html">Continue</a> = 'Conti'
         
-        binding:    Web(Angular) <span>{{person.name}}</span> = 'person.name' ou <span ng-bind="person.email"></span> = 'person.email'
-        
-        model:    Web(Angular) <input type="text" ng-model="person.name"/> = 'person.name'
          
         '''
-        self.driver.implicitly_wait(implicit)
+        
+        if(implicit!=None):  
+            self.driver.implicitly_wait(implicit)        
         if(tipo == 'id'):           
             elements=self.driver.find_elements_by_id(elemento)  
         elif(tipo == 'name'):
@@ -330,30 +321,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
             elements=self.driver.find_elements_by_partial_link_text(elemento)
         elif(tipo == 'css'):            
             elements=self.driver.find_elements_by_css_selector(elemento)
-        elif(self.angular==False):
-            if(tipo=='binding'):
-                elements=self.driver.find_elements_by_binding(elemento)
-            elif(tipo=='model'):
-                elements=self.driver.find_elements_by_model(elemento)
-            elif(tipo=='accessibility_id'):
-                elements=self.driver.find_elements_by_accessibility_id(elemento)
-            else:
-                Erro="""
-                    Escolha um valor de elemento Valido
-                    lista de elementos:
-                    id:    Web
-                    name:    Web
-                    class:    Web
-                    xpath:    Web
-                    link:    Web
-                    tag:    Web
-                    css:    Web
-                    partial_link:    Web
-                    binding:    Web(Angular)
-                    model:    Web(Angular)
-                    
-                    """
-                raise Elemento_erro(Erro)
+        
         else:
             Erro="""
                 Escolha um valor de elemento Valido
@@ -370,7 +338,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
             raise Elemento_erro(Erro)
         return elements
     
-    def elemento_por_texto(self,elemento_base,tipo,texto_referencia):
+    def elemento_por_texto(self,elemento_base,tipo,texto_referencia,implicit=None):
         '''Este metodo retorna em um elemento, baseado no texto referencia 
         na qual temos 3 parametros
         
@@ -389,14 +357,14 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
                  elemento_por_texto("gsfi","class",'texto valor')
         '''
         elemento=None
-        elements=self.elementos_list(elemento_base, tipo)
+        elements=self.elementos_list(elemento_base, tipo,implicit)
         for element in elements:
             if(element.text==texto_referencia):
                 elemento=element
         return elemento
     
     
-    def elemento_por_atributo(self,elemento_base,tipo,atributo_referencia,valor):
+    def elemento_por_atributo(self,elemento_base,tipo,atributo_referencia,valor,implicit=None):
         '''Este metodo retorna em um elemento, baseado no atributto referencia 
         na qual temos 3 parametros
         
@@ -414,6 +382,8 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
                 
                  elemento_por_texto("gsfi","class",'texto valor')
         '''
+        if(implicit!=None):  
+            self.driver.implicitly_wait(implicit)
         elemento=None
         elements=self.elementos_list(elemento_base, tipo)
         for element in elements:
@@ -421,7 +391,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
                 elemento=element
         return elemento
     
-    def escreve(self,elemento,conteudo,tipo,implicit=0,tempo=None):
+    def escreve(self,elemento,conteudo,tipo,implicit=None,tempo=None):
         '''Este metodo escreve em um elemento, na qual temos cinco parametros
         
         elemento(obrigatorio): Qual é o elemento que iremos buscar para realizar a escrita, necessariamente oque invididualiza seu ekemento pela descricao.
@@ -450,10 +420,10 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
             
         return element
     
-    def clica_elemento_atributo(self,elemento_base,tipo,atributo_referencia,valor):
-        self.elemento_por_atributo(elemento_base, tipo, atributo_referencia, valor).click()
+    def clica_elemento_atributo(self,elemento_base,tipo,atributo_referencia,valor,implicit=None):
+        self.elemento_por_atributo(elemento_base, tipo, atributo_referencia, valor,implicit).click()
         
-    def escreve_por_texto(self,elemento_base,tipo,conteudo,texto_referencia):
+    def escreve_por_texto(self,elemento_base,tipo,conteudo,texto_referencia,implicit=None):
         '''Este metodo escreve em um elemento, na qual temos cinco parametros
         
         elemento_base(obrigatorio): Qual é o elemento que iremos buscar para realizar a escrita, necessariamente oque invididualiza seu ekemento pela descricao.
@@ -471,7 +441,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
                  escreve_por_texto("gsfi","class",'Valor','texto valor')
         '''
        
-        elemento=self.elemento_por_texto(elemento_base, tipo, texto_referencia)    
+        elemento=self.elemento_por_texto(elemento_base, tipo, texto_referencia,implicit)    
         elemento.send_keys(conteudo)
         return elemento
     
@@ -495,7 +465,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         elemento.click()
         return elemento
            
-    def clica(self,elemento,tipo,implicit=0):
+    def clica(self,elemento,tipo,implicit=None):
         '''Este metodo clica em um elemento, na qual temos tres parametros
         
         elemento(obrigatorio): Qual é o elemento que iremos buscar para realizar a escrita, necessariamente oque invididualiza seu ekemento pela descricao.
@@ -516,7 +486,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         return element
              
     
-    def pegar_texto(self,elemento,tipo,implicit=0):
+    def pegar_texto(self,elemento,tipo,implicit=None):
         '''Este metodo retorna o texto de um elemento, na qual temos tres parametros
         
         retornara o texto que estiver no elemento
@@ -537,7 +507,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         element=self.elemento(elemento,tipo,implicit) 
         return element.text,element
                 
-    def escrever_elemento_lista(self,elemento,conteudo,tipo,indice_lista:int,implicit=0,tempo:int=None):
+    def escrever_elemento_lista(self,elemento,conteudo,tipo,indice_lista:int,implicit=None,tempo:int=None):
         '''Este metodo escreve em um elemento de uma lista de elementos com o mesmo tipo e elemento, na qual temos seis parametros
         
         elemento(obrigatorio): Qual é o elemento que iremos buscar para realizar a busca na lista de elementos com a mesma descricao
@@ -559,7 +529,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         element=self.elemento_list(elemento,tipo,indice_lista,implicit)
         element.send_keys(conteudo)     
             
-    def clica_elemento_lista(self,elemento,tipo,indice_lista:int,implicit=0):
+    def clica_elemento_lista(self,elemento,tipo,indice_lista:int,implicit=None):
         '''Este metodo clica em um elemento de uma lista de elementos com o mesmo tipo e elemento. na qual temos quatro parametros
         
         elemento(obrigatorio): Qual é o elemento que iremos buscar para realizar a busca na lista de elementos com a mesma descricao
@@ -580,7 +550,7 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
         element.click()
         return element 
     
-    def pegar_texto_list(self,elemento,tipo,indice_lista:int,implicit=0):
+    def pegar_texto_list(self,elemento,tipo,indice_lista:int,implicit=None):
         '''Este metodo retorna o texto de um elemento de uma lista de elementos com o mesmo tipo e elemento. na qual temos quatro parametros
         
         retornara o texto que estiver no elemento
@@ -600,4 +570,4 @@ class Web(Teclado,Mouse,Valida,Aguarde_elemento,Js_Script,Simula):
                 pegar_texto_list("input","tag",1,10)
         '''
         element=self.elementos_list(elemento,tipo,indice_lista,implicit)
-        return element.text    
\ No newline at end of file
+        return element.text 
\ No newline at end of file
